summaryrefslogtreecommitdiffstats
path: root/src/H5Gname.c
diff options
context:
space:
mode:
authorQuincey Koziol <koziol@hdfgroup.org>2012-04-01 22:27:15 (GMT)
committerQuincey Koziol <koziol@hdfgroup.org>2012-04-01 22:27:15 (GMT)
commit362f22119d9cb25424f7cdf181219bfa6330b6b8 (patch)
tree4ffa1e4be8fecd337594ef32cc1da95c16bdf615 /src/H5Gname.c
parent7022c013acb0ffac172d0ef99aa7d0205ab842c8 (diff)
downloadhdf5-362f22119d9cb25424f7cdf181219bfa6330b6b8.zip
hdf5-362f22119d9cb25424f7cdf181219bfa6330b6b8.tar.gz
hdf5-362f22119d9cb25424f7cdf181219bfa6330b6b8.tar.bz2
[svn-r22228] Description:
Bring r22219 from trunk to 1.8 branch: (with release manager's blessing) Merge "file image" changes from feature branch back to trunk. Tested on: h5committested
Diffstat (limited to 'src/H5Gname.c')
-rw-r--r--src/H5Gname.c11
1 files changed, 7 insertions, 4 deletions
diff --git a/src/H5Gname.c b/src/H5Gname.c
index 25639f2d..e925313 100644
--- a/src/H5Gname.c
+++ b/src/H5Gname.c
@@ -782,7 +782,7 @@ done:
/*-------------------------------------------------------------------------
* Function: H5G_name_replace_cb
*
* Purpose: H5I_search callback function to replace group entry names
*
* Return: Success: 0, Failure: -1
*
@@ -1166,15 +1166,18 @@ H5G_name_replace(const H5O_link_t *lnk, H5G_names_op_t op, H5F_t *src_file,
/* Search through group IDs */
if(search_group)
- H5I_search(H5I_GROUP, H5G_name_replace_cb, &names, FALSE);
+ if(H5I_iterate(H5I_GROUP, H5G_name_replace_cb, &names, FALSE) < 0)
+ HGOTO_ERROR(H5E_SYM, H5E_BADITER, FAIL, "can't iterate over groups")
/* Search through dataset IDs */
if(search_dataset)
- H5I_search(H5I_DATASET, H5G_name_replace_cb, &names, FALSE);
+ if(H5I_iterate(H5I_DATASET, H5G_name_replace_cb, &names, FALSE) < 0)
+ HGOTO_ERROR(H5E_SYM, H5E_BADITER, FAIL, "can't iterate over datasets")
/* Search through datatype IDs */
if(search_datatype)
- H5I_search(H5I_DATATYPE, H5G_name_replace_cb, &names, FALSE);
+ if(H5I_iterate(H5I_DATATYPE, H5G_name_replace_cb, &names, FALSE) < 0)
+ HGOTO_ERROR(H5E_SYM, H5E_BADITER, FAIL, "can't iterate over datatypes")
} /* end if */
} /* end if */
@@ -782,7 +782,7 @@ done:
* Function: H5G_name_replace_cb
*
- * Purpose: H5I_search callback function to replace group entry names
+ * Purpose: H5I_iterate callback function to replace group entry names
*
* Return: Success: 0, Failure: -1